@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class CreateJobConfigRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param EntrypointClass: 主类
@@ -45,6 +45,10 @@ class CreateJobConfigRequest(AbstractModel):
         :type COSBucket: str
         :param LogCollect: 是否采集作业日志
         :type LogCollect: bool
+        :param JobManagerSpec: JobManager规格
+        :type JobManagerSpec: float
+        :param TaskManagerSpec: TaskManager规格
+        :type TaskManagerSpec: float
         """
         self.JobId = None
         self.EntrypointClass = None
@@ -56,6 +60,8 @@ class CreateJobConfigRequest(AbstractModel):
         self.AutoDelete = None
         self.COSBucket = None
         self.LogCollect = None
+        self.JobManagerSpec = None
+        self.TaskManagerSpec = None
 
 
     def _deserialize(self, params):
@@ -79,12 +85,14 @@ class CreateJobConfigRequest(AbstractModel):
         self.AutoDelete = params.get("AutoDelete")
         self.COSBucket = params.get("COSBucket")
         self.LogCollect = params.get("LogCollect")
+        self.JobManagerSpec = params.get("JobManagerSpec")
+        self.TaskManagerSpec = params.get("TaskManagerSpec")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -94,7 +102,7 @@ class CreateJobConfigResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Version: 作业配置版本号
         :type Version: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -107,13 +115,6 @@ class CreateJobConfigResponse(AbstractModel):
     def _deserialize(self, params):
         self.Version = params.get("Version")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateJobRequest(AbstractModel):
@@ -122,7 +123,7 @@ class CreateJobRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 作业名称，允许输入长度小于等于50个字符的中文、英文、数字、-（横线）、_（下划线）、.（点），且符号必须半角字符。注意作业名不能和现有作业同名
         :type Name: str
         :param JobType: 作业的类型，1 表示 SQL 作业，2 表示 JAR 作业
@@ -135,6 +136,8 @@ class CreateJobRequest(AbstractModel):
         :type CuMem: int
         :param Remark: 作业的备注信息，可以随意设置
         :type Remark: str
+        :param FolderId: 作业名所属文件夹ID，根目录为"root"
+        :type FolderId: str
         """
         self.Name = None
         self.JobType = None
@@ -142,6 +145,7 @@ class CreateJobRequest(AbstractModel):
         self.ClusterId = None
         self.CuMem = None
         self.Remark = None
+        self.FolderId = None
 
 
     def _deserialize(self, params):
@@ -151,12 +155,13 @@ class CreateJobRequest(AbstractModel):
         self.ClusterId = params.get("ClusterId")
         self.CuMem = params.get("CuMem")
         self.Remark = params.get("Remark")
+        self.FolderId = params.get("FolderId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -166,7 +171,7 @@ class CreateJobResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -179,13 +184,6 @@ class CreateJobResponse(AbstractModel):
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateResourceConfigRequest(AbstractModel):
@@ -194,7 +192,7 @@ class CreateResourceConfigRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param ResourceLoc: 位置信息
@@ -222,7 +220,7 @@ class CreateResourceConfigRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -232,7 +230,7 @@ class CreateResourceConfigResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Version: 资源版本ID
         :type Version: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -245,13 +243,6 @@ class CreateResourceConfigResponse(AbstractModel):
     def _deserialize(self, params):
         self.Version = params.get("Version")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateResourceRequest(AbstractModel):
@@ -260,7 +251,7 @@ class CreateResourceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceLoc: 资源位置
         :type ResourceLoc: :class:`tencentcloud.oceanus.v20190422.models.ResourceLoc`
         :param Name: 资源名称
@@ -292,7 +283,7 @@ class CreateResourceRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -302,7 +293,7 @@ class CreateResourceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param Version: 资源版本
@@ -319,13 +310,6 @@ class CreateResourceResponse(AbstractModel):
         self.ResourceId = params.get("ResourceId")
         self.Version = params.get("Version")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DeleteResourceConfigsRequest(AbstractModel):
@@ -334,7 +318,7 @@ class DeleteResourceConfigsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param ResourceConfigVersions: 资源版本数组
@@ -352,7 +336,7 @@ class DeleteResourceConfigsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -362,7 +346,7 @@ class DeleteResourceConfigsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -371,13 +355,6 @@ class DeleteResourceConfigsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DeleteResourcesRequest(AbstractModel):
@@ -386,7 +363,7 @@ class DeleteResourcesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceIds: 待删除资源ID列表
         :type ResourceIds: list of str
         """
@@ -400,7 +377,7 @@ class DeleteResourcesRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -410,7 +387,7 @@ class DeleteResourcesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -419,13 +396,6 @@ class DeleteResourcesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DeleteTableConfigRequest(AbstractModel):
@@ -434,7 +404,7 @@ class DeleteTableConfigRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业ID
         :type JobId: str
         :param DebugId: 调试作业ID
@@ -456,7 +426,7 @@ class DeleteTableConfigRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -466,7 +436,7 @@ class DeleteTableConfigResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -475,13 +445,6 @@ class DeleteTableConfigResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeJobConfigsRequest(AbstractModel):
@@ -490,7 +453,7 @@ class DescribeJobConfigsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param JobConfigVersions: 作业配置版本
@@ -529,7 +492,7 @@ class DescribeJobConfigsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -539,7 +502,7 @@ class DescribeJobConfigsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总的配置版本数量
         :type TotalCount: int
         :param JobConfigSet: 作业配置列表
@@ -561,13 +524,6 @@ class DescribeJobConfigsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.JobConfigSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeJobsRequest(AbstractModel):
@@ -576,7 +532,7 @@ class DescribeJobsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobIds: 按照一个或者多个作业ID查询。作业ID形如：cql-11112222，每次请求的作业上限为100。参数不支持同时指定JobIds和Filters。
         :type JobIds: list of str
         :param Filters: 过滤条件，支持的 Filter.Name 为：作业名 Name、作业状态 Status、所属集群 ClusterId。每次请求的 Filters 个数的上限为 3，Filter.Values 的个数上限为 5。参数不支持同时指定 JobIds 和 Filters。
@@ -607,7 +563,7 @@ class DescribeJobsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -617,7 +573,7 @@ class DescribeJobsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 作业总数
         :type TotalCount: int
         :param JobSet: 作业列表
@@ -639,13 +595,6 @@ class DescribeJobsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.JobSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeResourceConfigsRequest(AbstractModel):
@@ -654,7 +603,7 @@ class DescribeResourceConfigsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param Offset: 偏移量，仅当设置 Limit 时该参数有效
@@ -688,7 +637,7 @@ class DescribeResourceConfigsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -698,7 +647,7 @@ class DescribeResourceConfigsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceConfigSet: 资源配置描述数组
         :type ResourceConfigSet: list of ResourceConfigItem
         :param TotalCount: 资源配置数量
@@ -720,13 +669,6 @@ class DescribeResourceConfigsResponse(AbstractModel):
                 self.ResourceConfigSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeResourceRelatedJobsRequest(AbstractModel):
@@ -735,7 +677,7 @@ class DescribeResourceRelatedJobsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param DESCByJobConfigCreateTime: 默认0;   1： 按照作业版本创建时间降序
@@ -761,7 +703,7 @@ class DescribeResourceRelatedJobsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -771,7 +713,7 @@ class DescribeResourceRelatedJobsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数
         :type TotalCount: int
         :param RefJobInfos: 关联作业信息
@@ -793,13 +735,6 @@ class DescribeResourceRelatedJobsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.RefJobInfos.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeResourcesRequest(AbstractModel):
@@ -808,14 +743,15 @@ class DescribeResourcesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param ResourceIds: 需要查询的资源ID数组
+        r"""
+        :param ResourceIds: 需要查询的资源ID数组，数量不超过100个。如果填写了该参数则忽略Filters参数。
         :type ResourceIds: list of str
         :param Offset: 偏移量，仅当设置 Limit 参数时有效
         :type Offset: int
         :param Limit: 条数限制。如果不填，默认返回 20 条
         :type Limit: int
-        :param Filters: 查询资源配置列表， 如果不填写，返回该ResourceId下所有作业配置列表
+        :param Filters: <li><strong>ResourceName</strong></li>
+<p style="padding-left: 30px;">按照资源名字过滤，支持模糊过滤。传入的过滤名字不超过5个</p><p style="padding-left: 30px;">类型: String</p><p style="padding-left: 30px;">必选: 否</p>
         :type Filters: list of Filter
         """
         self.ResourceIds = None
@@ -839,7 +775,7 @@ class DescribeResourcesRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -849,7 +785,7 @@ class DescribeResourcesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceSet: 资源详细信息集合
         :type ResourceSet: list of ResourceItem
         :param TotalCount: 总数量
@@ -871,13 +807,6 @@ class DescribeResourcesResponse(AbstractModel):
                 self.ResourceSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeSystemResourcesRequest(AbstractModel):
@@ -886,7 +815,7 @@ class DescribeSystemResourcesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceIds: 需要查询的资源ID数组
         :type ResourceIds: list of str
         :param Offset: 偏移量，仅当设置 Limit 参数时有效
@@ -921,7 +850,7 @@ class DescribeSystemResourcesRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -931,7 +860,7 @@ class DescribeSystemResourcesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceSet: 资源详细信息集合
         :type ResourceSet: list of SystemResourceItem
         :param TotalCount: 总数量
@@ -953,13 +882,6 @@ class DescribeSystemResourcesResponse(AbstractModel):
                 self.ResourceSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class Filter(AbstractModel):
@@ -968,7 +890,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 要过滤的字段
         :type Name: str
         :param Values: 字段的过滤值
@@ -986,7 +908,7 @@ class Filter(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -996,7 +918,7 @@ class JobConfig(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param EntrypointClass: 主类
@@ -1036,6 +958,12 @@ class JobConfig(AbstractModel):
         :param MaxParallelism: 作业的最大并行度
 注意：此字段可能返回 null，表示取不到有效值。
         :type MaxParallelism: int
+        :param JobManagerSpec: JobManager规格
+注意：此字段可能返回 null，表示取不到有效值。
+        :type JobManagerSpec: float
+        :param TaskManagerSpec: TaskManager规格
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskManagerSpec: float
         """
         self.JobId = None
         self.EntrypointClass = None
@@ -1051,6 +979,8 @@ class JobConfig(AbstractModel):
         self.COSBucket = None
         self.LogCollect = None
         self.MaxParallelism = None
+        self.JobManagerSpec = None
+        self.TaskManagerSpec = None
 
 
     def _deserialize(self, params):
@@ -1078,12 +1008,14 @@ class JobConfig(AbstractModel):
         self.COSBucket = params.get("COSBucket")
         self.LogCollect = params.get("LogCollect")
         self.MaxParallelism = params.get("MaxParallelism")
+        self.JobManagerSpec = params.get("JobManagerSpec")
+        self.TaskManagerSpec = params.get("TaskManagerSpec")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1093,7 +1025,7 @@ class JobV1(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type JobId: str
@@ -1115,7 +1047,7 @@ class JobV1(AbstractModel):
         :param Name: 作业名字
 注意：此字段可能返回 null，表示取不到有效值。
         :type Name: str
-        :param JobType: 作业类型
+        :param JobType: 作业类型，1：sql作业，2：Jar作业
 注意：此字段可能返回 null，表示取不到有效值。
         :type JobType: int
         :param Status: 作业状态，1：未初始化，2：未发布，3：操作中，4：运行中，5：停止，6：暂停，-1：故障
@@ -1175,6 +1107,9 @@ class JobV1(AbstractModel):
         :param ClusterStatus: 作业所在集群状态
 注意：此字段可能返回 null，表示取不到有效值。
         :type ClusterStatus: int
+        :param RunningCu: 细粒度下的运行的CU数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RunningCu: float
         """
         self.JobId = None
         self.Region = None
@@ -1203,6 +1138,7 @@ class JobV1(AbstractModel):
         self.WebUIUrl = None
         self.SchedulerType = None
         self.ClusterStatus = None
+        self.RunningCu = None
 
 
     def _deserialize(self, params):
@@ -1233,12 +1169,13 @@ class JobV1(AbstractModel):
         self.WebUIUrl = params.get("WebUIUrl")
         self.SchedulerType = params.get("SchedulerType")
         self.ClusterStatus = params.get("ClusterStatus")
+        self.RunningCu = params.get("RunningCu")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1248,7 +1185,7 @@ class Property(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Key: 系统配置的Key
         :type Key: str
         :param Value: 系统配置的Value
@@ -1266,7 +1203,7 @@ class Property(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1276,7 +1213,7 @@ class ResourceConfigItem(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param ResourceType: 资源类型
@@ -1338,7 +1275,7 @@ class ResourceConfigItem(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1348,7 +1285,7 @@ class ResourceItem(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param Name: 资源名称
@@ -1419,7 +1356,7 @@ class ResourceItem(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1429,8 +1366,8 @@ class ResourceLoc(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param StorageType: 资源位置的存储类型，目前只支持COS
+        r"""
+        :param StorageType: 资源位置的存储类型，目前只支持1:COS
         :type StorageType: int
         :param Param: 描述资源位置的json
         :type Param: :class:`tencentcloud.oceanus.v20190422.models.ResourceLocParam`
@@ -1449,7 +1386,7 @@ class ResourceLoc(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1459,7 +1396,7 @@ class ResourceLocParam(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Bucket: 资源bucket
         :type Bucket: str
         :param Path: 资源路径
@@ -1482,7 +1419,7 @@ class ResourceLocParam(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1492,7 +1429,7 @@ class ResourceRef(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param Version: 资源版本ID，-1表示使用最新版本
@@ -1514,7 +1451,7 @@ class ResourceRef(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1524,7 +1461,7 @@ class ResourceRefDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源id
         :type ResourceId: str
         :param Version: 资源版本，-1表示使用最新版本
@@ -1554,7 +1491,7 @@ class ResourceRefDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1564,7 +1501,7 @@ class ResourceRefJobInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: Job id
         :type JobId: str
         :param JobConfigVersion: Job配置版本
@@ -1586,7 +1523,7 @@ class ResourceRefJobInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1596,7 +1533,7 @@ class RunJobDescription(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param RunType: 运行类型，1：启动，2：恢复
@@ -1622,7 +1559,7 @@ class RunJobDescription(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1632,7 +1569,7 @@ class RunJobsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RunJobDescriptions: 批量启动作业的描述信息
         :type RunJobDescriptions: list of RunJobDescription
         """
@@ -1651,7 +1588,7 @@ class RunJobsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1661,7 +1598,7 @@ class RunJobsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1670,13 +1607,6 @@ class RunJobsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class StopJobDescription(AbstractModel):
@@ -1685,7 +1615,7 @@ class StopJobDescription(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param JobId: 作业Id
         :type JobId: str
         :param StopType: 停止类型，1 停止 2 暂停
@@ -1703,7 +1633,7 @@ class StopJobDescription(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1713,7 +1643,7 @@ class StopJobsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StopJobDescriptions: 批量停止作业的描述信息
         :type StopJobDescriptions: list of StopJobDescription
         """
@@ -1732,7 +1662,7 @@ class StopJobsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1742,7 +1672,7 @@ class StopJobsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1751,13 +1681,6 @@ class StopJobsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SystemResourceItem(AbstractModel):
@@ -1766,7 +1689,7 @@ class SystemResourceItem(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源ID
         :type ResourceId: str
         :param Name: 资源名称
@@ -1800,5 +1723,5 @@ class SystemResourceItem(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
